#
# spec file for package kalendar
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __requires_exclude qmlimport\\((org\\.kde\\.merkuro\\.1|org\\.kde\\.raven).*
%define kf5_version 5.105.0
%bcond_without released
Name:           merkuro
Version:        23.08.5
Release:        bp156.1.2
Summary:        Calendar Application
License:        GPL-3.0-only
URL:            https://apps.kde.org/merkuro.calendar
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{kf5_version}
%if 0%{?suse_version} == 1500
BuildRequires:  gcc10-c++
BuildRequires:  gcc10-PIE
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5CalendarCore)
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5Contacts)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5ItemModels)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Kirigami2)
BuildRequires:  cmake(KF5KirigamiAddons)
BuildRequires:  cmake(KPim5PimCommonAkonadi)
BuildRequires:  cmake(KF5Plasma)
BuildRequires:  cmake(KF5QQC2DesktopStyle)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(KPim5Akonadi)
BuildRequires:  cmake(KPim5AkonadiCalendar)
BuildRequires:  cmake(KPim5AkonadiContact)
BuildRequires:  cmake(KPim5AkonadiMime)
BuildRequires:  cmake(KPim5CalendarSupport)
BuildRequires:  cmake(KPim5EventViews)
BuildRequires:  cmake(KPim5MailCommon)
BuildRequires:  cmake(Qt5Core) >= 5.15.2
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5QuickTest)
BuildRequires:  pkgconfig(gpgme)
Requires:       kalendarac
Requires:       kdepim-addons
Requires:       kdepim-runtime
# No automatic qmlimport requires for embedded resources :-/
Requires:       kirigami2 >= %{kf5_version}
Requires:       qt5qmlimport(QtGraphicalEffects.1)
Requires:       qt5qmlimport(QtLocation.5)
Requires:       qt5qmlimport(QtQuick.Dialogs.1)
Requires:       qt5qmlimport(org.kde.kitemmodels.1)
Provides:       kalendar = %{version}
Obsoletes:      kalendar < %{version}
# Got vendored for now
# Requires:       qt5qmlimport(org.kde.kirigamiaddons.treeview.1)
# kalendar has a runtime dependency on QtWebEngine
ExclusiveArch:  %{ix86} x86_64 %{arm} aarch64 riscv64

%description
Calendar application using Akonadi to sync with external services (NextCloud, GMail, ...).

%package plasmoid
Summary:        Plasma widget to view address book contacts
Supplements:    (%{name} and plasma5-workspace)
Requires:       %{name} = %{version}
Provides:       kalendar-plasmoid = %{version}
Obsoletes:      kalendar-plasmoid < %{version}

%description plasmoid
This package provides a Plasma widget to view address book contacts.

%lang_package

%prep
%autosetup -p1

%build
%if 0%{?suse_version} == 1500
  export CXX=g++-10
%endif

%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --with-man --all-name

%files
%license LICENSES/*
%dir %{_kf5_qmldir}/org/kde/merkuro/
%{_kf5_applicationsdir}/org.kde.merkuro.contact.desktop
%{_kf5_applicationsdir}/org.kde.merkuro.mail.desktop
%{_kf5_applicationsdir}/org.kde.merkuro.calendar.desktop
%{_kf5_bindir}/merkuro-mail
%{_kf5_bindir}/merkuro-calendar
%{_kf5_bindir}/merkuro-contact
%{_kf5_debugdir}/akonadi.quick.categories
%{_kf5_debugdir}/merkuro.categories
%{_kf5_debugdir}/merkuro.contact.categories
%{_kf5_iconsdir}/hicolor/*/apps/org.kde.merkuro.*.png
%{_kf5_qmldir}/org/kde/akonadi/
%{_kf5_qmldir}/org/kde/merkuro/contact/
%{_kf5_qmldir}/org/kde/merkuro/calendar/
%{_kf5_qmldir}/org/kde/merkuro/mail/
%{_kf5_qmldir}/org/kde/merkuro/components/
%{_kf5_appstreamdir}/org.kde.merkuro.calendar.metainfo.xml
%{_kf5_appstreamdir}/org.kde.merkuro.mail.metainfo.xml
%{_kf5_appstreamdir}/org.kde.merkuro.contact.metainfo.xml

%files plasmoid
%dir %{_kf5_plasmadir}/plasmoids
%{_kf5_appstreamdir}/org.kde.merkuro.contact.appdata.xml
%{_kf5_plasmadir}/plasmoids/org.kde.merkuro.contact

%files lang -f %{name}.lang

%changelog
* Tue Mar 26 2024 Christophe Marin <christophe@krop.fr>
- Update to 23.08.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.5/
- Changes since 23.08.4:
  * snapcraft: Use akonadi-sdk for build snap.
  * snapcraft: New content pack release.
  * snapcraft: fix syntax.
  * snapcraft: add akonadi to root path.
  * snapcraft: add license text.
  * snapcraft: New release.
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- Changes since 23.08.3:
  * Fix wrong bug url (kde#477373)
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * snapcraft: let appstream set version. refresh dependencies.
  * Ensure we mark element as selected in contact list
  * Typo in reuse for snapcraft.yaml
  * Add snapcraft.yaml to reuse.
  * snapcraft: initial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * Fix more issue with wrong date due to timezone
  * Fix shifting of date by one day/month (kde#473866)
  * Fix displaying of Basic HourlyView
  * DateUtils: Trim userProvidedYear to remove whitespace before parsing
  * Fix invalid parent collection error
  * fix triggering mailto: and tel: actions twice
  * fixes bug in photoEditor.qml
  * Fix crash when running merkuro with other locales (kde#474191)
  * Fix adding new contact (kde#474380)
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Fix ViewMenu.qml
  * Fix segfault on launch (kde#473618)
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Fix collapsed status of collectionHeadingItem
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- kalendar was renamed to merkuro
- Update to 23.07.80
  * New feature release
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Store reminder times to the correct variable (kde#470288)
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Move RemindersModel to calendar module
  * Simplify MultiDayIncidenceModel
  * Use grouped property
  * Modernize DayGridView
  * BasicMonthGridView.qml: Use const instead of let
  * Use strict equality for DayGridViewIncidenceDelegate.isInCurrentMonth
  * Remove usage of KCalPrefs
  * Use Akonadi::Collection::Id to store color keys
  * Improve retrival of color from incidence
  * Get collection color directly from collection when possible in IncidenceOccurrenceModel
  * Fix wrong colour being set in color cache when generating it is required
  * Disable capturing hover events globally
  * Fix bugs in IncidenceInfoContents
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Remove qml debugger
  * Fix incidenceoccurrencemodel tests
  * Fix checking if a non existing calendar (kde#463739)
  * Fix "Custom" reminder option showing as "On Event Start"
  * Fix crashes in incidenceoccurrencemodel (kde#466063)
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Use qmlimport dependencies for public org.kde.kalendar.*
- Drop requires on nonexisting -import subpackage
- Install the plasmoid with kalendar if plasma5-workspace is installed
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Fri Aug 19 2022 Christophe Giboudeaux <christophe@krop.fr>
- Merge -imports and the main kalendar package.
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Thu Mar 24 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Kalendar is now released with other KDE Gear.
- Drop obsolete patch:
  * 0001-Use-categorized-logging-in-the-reminder-daemon.patch
* Sat Feb 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.0.0
- Add patch to avoid excessive logging:
  * 0001-Use-categorized-logging-in-the-reminder-daemon.patch
* Sat Oct 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Initial packaging
